@@ -209,7 +209,7 @@ class Task(APIResource):
         response = requestor.post(url=cls._CLASS_PREFIX, body=task_config, api_key=api_key)
         id = response['task_id']
         if wait:
-            utils.wait_for_finite_state(cls.get, id, api_key=api_key)
+            utils.wait_for_finite_state(cls.get, id, max_time=timeout, api_key=api_key)
             response = cls.get(id, api_key=api_key)
         else:
             response = WhatifyResponse(data={'id': id})
