@@ -59,7 +59,6 @@ class UserManagement(APIResource):
             WhatifyResponse: Empty WhatifyResponse if successful, raises FireflyError otherwise.
         """
         url = 'login'
-
         requestor = APIRequestor()
         response = requestor.post(url, body={'username': email, 'password': password, 'tnc': None}, api_key="")
         toolkit_w.token = response['token']
@@ -68,7 +67,7 @@ class UserManagement(APIResource):
         return WhatifyResponse(status_code=response.status_code, headers=response.headers)
 
     @classmethod
-    def impersonate(cls, user_id: str = None, email: str = None, admin_token: str = None) -> WhatifyResponse:
+    def impersonate(cls, user_id: str = None, admin_token: str = None) -> WhatifyResponse:
         """
        impersonate user and stores temporary token in `toolkit_w.token`
 
@@ -80,15 +79,16 @@ class UserManagement(APIResource):
        Returns:
            WhatifyResponse: Empty WhatifyResponse if successful, raises WhatifyError otherwise.
        """
-        if email:
-            user_id = None
-            raise Exception('TODO: need tom implement get user ID from mail')
-
         url = ''.join(['users/login_as/', str(user_id)])
         requester = APIRequestor()
-        response = requester.post(url, api_key=admin_token)
-        toolkit_w.token = response['result']
-        print(' '.join(['user ID:', str(user_id), '- Login successful']))
+        try:
+            response = requester.post(url, api_key=admin_token)
+            toolkit_w.token = response['result']
+            print(' '.join(['user ID:', str(user_id), '- Login successful']))
+        except Exception as ex:
+            print(' '.join(['user ID:', str(user_id), '- Login Failed']))
+            raise ex
+
         return WhatifyResponse(status_code=response.status_code, headers=response.headers)
 
     @classmethod
@@ -107,6 +107,26 @@ class UserManagement(APIResource):
             ret_val = resp['result'][0]
         return ret_val
 
+    @classmethod
+    def get_user_id(cls, email: str = None):
+        user_id = -1
+        if email:
+            user = cls.get_user_list(username=email)
+            if user:
+                user_id = user['user_id']
+        else:
+            user_id = cls.user_token.get_user_id()
+        return user_id
+
+    @classmethod
+    def get_account_id(cls, email: str = None):
+        account_id = -1
+        if email:
+            account = cls.get_account_list(name=email)
+            if account:
+                account_id = account['id']
+        return account_id
+
     # @classmethod
     # def test_API(cls, var_str: str, user_token: str = None) -> WhatifyResponse:
     #     print('aa' + str(var_str))
