@@ -53,12 +53,10 @@ class MyWhatify:
         with allure.step('login with user: ' + str(email)):
             logging.info('login with user: ' + str(email))  # + ' and password: ' + password)
             my_toolkit.UserManagement.login(email=email, password=password)
-            if imp_email:
-                with allure.step('getting user ID from email'):
-                    user_id = cls.get_user_id(imp_email)
-            if user_id and user_id != -1:
-                with allure.step(' '.join(['impersonate to user_ID:', str(user_id)])):
-                    my_toolkit.UserManagement.impersonate(user_id=user_id)
+
+            if user_id or imp_email:
+                cls.impersonate(user_id=user_id, email=imp_email)
+
             cls.user_token = UserToken(my_toolkit.token)
 
     @classmethod
@@ -70,16 +68,7 @@ class MyWhatify:
 
         :return: user ID or -1 if not exist
         """
-        user_id = -1
-        with allure.step('get user ID for current user or for user: ' + str(email)):
-            logging.info('get user ID for current user or for user: ' + str(email))
-            if email:
-                user = my_toolkit.UserManagement.get_user_list(username=email)
-                if user:
-                    user_id = user['user_id']
-            else:
-                user_id = cls.user_token.get_user_id()
-        return user_id
+        return my_toolkit.UserManagement.get_user_id(email=email)
 
     @classmethod
     def get_account_id(cls, email: str = None):
@@ -90,14 +79,7 @@ class MyWhatify:
 
         :return: account ID or -1 if not exist
         """
-        account_id = -1
-        with allure.step('get account ID for current user or for user: ' + str(email)):
-            logging.info('get account ID for current user or for user: ' + str(email))
-            if email:
-                account = my_toolkit.UserManagement.get_account_list(name=email)
-                if account:
-                    account_id = account['id']
-        return account_id
+        return my_toolkit.UserManagement.get_account_id(email=email)
 
     @classmethod
     def impersonate(cls, user_id=None, email: str = None, admin_token: str = None):
@@ -109,7 +91,13 @@ class MyWhatify:
         :param admin_token: the admin token to do impersonate
         """
         with allure.step(' '.join(['impersonate to user_ID:', str(user_id)])):
-            my_toolkit.UserManagement.impersonate(email=email, user_id=user_id, admin_token=admin_token)
+            if email:
+                with allure.step('getting user ID from email'):
+                    user_id = cls.get_user_id(email=email)
+
+            with allure.step(' '.join(['impersonate to user_ID:', str(user_id)])):
+                my_toolkit.UserManagement.impersonate(user_id=user_id, admin_token=admin_token)
+
 
     #############################
     #######    API's      #######
@@ -556,9 +544,7 @@ class MyWhatify:
         with allure.step('getting csv from data file for data_name: ' + str(data_name)):
             # script_dir = os.getcwd()
             # script_dir = os.path.dirname(__file__)
-            # path = os.path.join(script_dir, 'data_source/', data_name)
-            path = os.path.join(os.getcwd(), 'data_source/', data_name)
-            # path = os.path.join('/home/moshe/Downloads/work/Whatify_Toolkit/toolkit_w', 'data_source/', data_name)
+            path = os.path.join(os.path.dirname(__file__), 'data_source/', data_name)
             # path = "https://raw.githubusercontent.com/NeuralAlgorithms/firefly-python-sdk/master/examples/"
         return pd.read_csv(path)
 
